==> owncloud-8.2.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_sharing/l10n/cs_CZ.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Sdílení mezi servery není povoleno",
    "The mountpoint name contains invalid characters." : "Jméno přípojného bodu obsahuje nepovolené znaky.",
    "Invalid or untrusted SSL certificate" : "Neplatný nebo nedůvěryhodný SSL certifikát",
    "Could not authenticate to remote share, password might be wrong" : "Nezdařilo se ověření vzdáleného úložiště, pravděpodobně chybné heslo",
    "Storage not valid" : "Úložiště není platné",
    "Couldn't add remote share" : "Nelze přidat vzdálené úložiště",
    "Shared with you" : "Sdíleno s vámi",
    "Shared with others" : "Sdíleno s ostatními",
    "Shared by link" : "Sdíleno pomocí odkazu",
    "Nothing shared with you yet" : "Zatím s vámi nikdo nic nesdílel",
    "Files and folders others share with you will show up here" : "Zde budou zobrazeny soubory a adresáře, které s vámi ostatní sdílí",
    "Nothing shared yet" : "Zatím není nic sdíleno",
    "Files and folders you share will show up here" : "Zde budou zobrazeny vámi sdílené soubory a adresáře",
    "No shared links" : "Žádné sdílené odkazy",
    "Files and folders you share by link will show up here" : "Zde budou zobrazeny soubory a adresáře, které sdílíte jako webové odkazy",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Chcete přidat vzdálené úložiště {name} uživatele {owner}@{remote}?",
    "Remote share" : "Vzdálené úložiště",
    "Remote share password" : "Heslo ke vzdálenému úložišti",
    "Cancel" : "Zrušit",
    "Add remote share" : "Přidat vzdálené úložiště",
    "You can upload into this folder" : "Můžete nahrávat do tohoto adresáře",
    "No ownCloud installation (7 or higher) found at {remote}" : "Nebyla nalezena instalace ownCloud (7 nebo vyšší) na {remote}",
    "Invalid ownCloud url" : "Neplatná ownCloud url",
    "Shared by" : "Sdílí",
    "Sharing" : "Sdílení",
    "A file or folder has been <strong>shared</strong>" : "Soubor nebo složka byla <strong>nasdílena</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Soubor nebo složka byla nasdílena z <strong>jiného serveru</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Byl <strong>stažen</strong> veřejně sdílený soubor nebo adresář",
    "You received a new remote share %2$s from %1$s" : "Obdrželi jste nové vzdálené sdílení %2$s od uživatele %1$s",
    "You received a new remote share from %s" : "Obdrželi jste nové vzdálené sdílení z %s",
    "%1$s accepted remote share %2$s" : "%1$s přijal(a) vzdálené sdílení %2$s",
    "%1$s declined remote share %2$s" : "%1$s odmítl(a) vzdálené sdílení %2$s",
    "%1$s unshared %2$s from you" : "%1$s již více nesdílí %2$s",
    "Public shared folder %1$s was downloaded" : "Byl stažen veřejně sdílený adresář %1$s ",
    "Public shared file %1$s was downloaded" : "Byl stažen veřejně sdílený soubor %1$s ",
    "You shared %1$s with %2$s" : "Sdílíte %1$s s %2$s",
    "You shared %1$s with group %2$s" : "Sdílíte %1$s se skupinou %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s nasdílel(a) %1$s s %3$s",
    "%2$s shared %1$s with group %3$s" : "%2$s nasdílel(a) %1$s se skupinou %3$s",
    "%2$s shared %1$s via link" : "%2$s nasdílel(a) %1$s jako odkaz",
    "%2$s shared %1$s with you" : "%2$s s vámi sdílí %1$s",
    "You shared %1$s via link" : "Sdílíte %1$s přes odkaz",
    "Downloaded via public link" : "Staženo pomocí veřejného odkazu",
    "Shared with %2$s" : "Sdíleno s %2$s",
    "Shared with group %2$s" : "Sdíleno se skupinou %2$s",
    "Shared with %3$s by %2$s" : "%2$s sdílí s %3$s",
    "Shared with group %3$s by %2$s" : "%2$s sdílí se skupinou %3$s",
    "Shared via link by %2$s" : "%2$s sdílel(a) jako odkaz",
    "Shared by %2$s" : "%2$s sdílel(a)",
    "Shared via public link" : "Sdíleno jako veřejný odkaz",
    "Shares" : "Sdílení",
    "Accept" : "Přijmout",
    "Decline" : "Zamítnout",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Sdílej se mnou pomocí mého #ownCloud sdruženého cloud ID, více na %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Sdílej se mnou pomocí mého #ownCloud sdruženého cloud ID",
    "This share is password-protected" : "Toto sdílení je chráněno heslem",
    "The password is wrong. Try again." : "Heslo není správné. Zkuste to znovu.",
    "Password" : "Heslo",
    "No entries found in this folder" : "V tomto adresáři nebylo nic nalezeno",
    "Name" : "Název",
    "Share time" : "Čas sdílení",
    "Sorry, this link doesn’t seem to work anymore." : "Je nám líto, ale tento odkaz již není funkční.",
    "Reasons might be:" : "Možné důvody:",
    "the item was removed" : "položka byla odebrána",
    "the link expired" : "platnost odkazu vypršela",
    "sharing is disabled" : "sdílení je zakázané",
    "For more info, please ask the person who sent this link." : "Pro více informací kontaktujte osobu, která vám zaslala tento odkaz.",
    "Add to your ownCloud" : "Přidat do svého ownCloudu",
    "Download" : "Stáhnout",
    "Download %s" : "Stáhnout %s",
    "Direct link" : "Přímý odkaz",
    "Federated Cloud Sharing" : "Propojené cloudové sdílení",
    "Open documentation" : "Otevřít dokumentaci",
    "Allow users on this server to send shares to other servers" : "Povolit uživatelům z tohoto serveru zasílat sdílení na jiné servery",
    "Allow users on this server to receive shares from other servers" : "Povolit uživatelům z tohoto serveru přijímat sdílení z jiných serverů",
    "Federated Cloud" : "Sdružený cloud",
    "Your Federated Cloud ID:" : "Vaše sdružené cloud ID:",
    "Share it:" : "Sdílet:",
    "Add to your website" : "Přidat na svou webovou stránku",
    "Share with me via ownCloud" : "Sdíleno se mnou přes ownCloud",
    "HTML Code:" : "HTML kód:"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");

==> owncloud-9.0.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_sharing/l10n/cs_CZ.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Sdílení mezi servery není povoleno",
    "The mountpoint name contains invalid characters." : "Jméno přípojného bodu obsahuje nepovolené znaky.",
    "Not allowed to create a federated share with the same user server" : "Není povoleno vytvořit propojené sdílení s tím samým serverem",
    "Invalid or untrusted SSL certificate" : "Neplatný nebo nedůvěryhodný SSL certifikát",
    "Could not authenticate to remote share, password might be wrong" : "Nezdařilo se ověření vzdáleného úložiště, pravděpodobně chybné heslo",
    "Storage not valid" : "Úložiště není platné",
    "Couldn't add remote share" : "Nelze přidat vzdálené úložiště",
    "Shared with you" : "Sdíleno s vámi",
    "Shared with others" : "Sdíleno s ostatními",
    "Shared by link" : "Sdíleno pomocí odkazu",
    "Federated sharing" : "Propojené sdílení",
    "Nothing shared with you yet" : "Zatím s vámi nikdo nic nesdílel",
    "Files and folders others share with you will show up here" : "Zde budou zobrazeny soubory a adresáře, které s vámi ostatní sdílí",
    "Nothing shared yet" : "Zatím není nic sdíleno",
    "Files and folders you share will show up here" : "Zde budou zobrazeny vámi sdílené soubory a adresáře",
    "No shared links" : "Žádné sdílené odkazy",
    "Files and folders you share by link will show up here" : "Zde budou zobrazeny soubory a adresáře, které sdílíte jako webové odkazy",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Chcete přidat vzdálené úložiště {name} uživatele {owner}@{remote}?",
    "Remote share" : "Vzdálené úložiště",
    "Remote share password" : "Heslo ke vzdálenému úložišti",
    "Cancel" : "Zrušit",
    "Add remote share" : "Přidat vzdálené úložiště",
    "You can upload into this folder" : "Můžete nahrávat do tohoto adresáře",
    "No ownCloud installation (7 or higher) found at {remote}" : "Nebyla nalezena instalace ownCloud (7 nebo vyšší) na {remote}",
    "Invalid ownCloud url" : "Neplatná ownCloud url",
    "Shared by" : "Sdílí",
    "Sharing" : "Sdílení",
    "A file or folder has been <strong>shared</strong>" : "Soubor nebo složka byla <strong>nasdílena</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Soubor nebo složka byla nasdílena z <strong>jiného serveru</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Byl <strong>stažen</strong> veřejně sdílený soubor nebo adresář",
    "You received a new remote share %2$s from %1$s" : "Obdrželi jste nové vzdálené sdílení %2$s od uživatele %1$s",
    "You received a new remote share from %s" : "Obdrželi jste nové vzdálené sdílení z %s",
    "%1$s accepted remote share %2$s" : "%1$s přijal(a) vzdálené sdílení %2$s",
    "%1$s declined remote share %2$s" : "%1$s odmítl(a) vzdálené sdílení %2$s",
    "%1$s unshared %2$s from you" : "%1$s již více nesdílí %2$s",
    "Public shared folder %1$s was downloaded" : "Byl stažen veřejně sdílený adresář %1$s ",
    "Public shared file %1$s was downloaded" : "Byl stažen veřejně sdílený soubor %1$s ",
    "You shared %1$s with %2$s" : "Sdílíte %1$s s %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s nasdílel(a) %1$s s %3$s",
    "You removed the share of %2$s for %1$s" : "Odstranil(a) jsi sdílení %2$s pro %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s odstranil(a) sdílení %3$s pro %1$s",
    "You shared %1$s with group %2$s" : "Sdílíte %1$s se skupinou %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s nasdílel(a) %1$s se skupinou %3$s",
    "You removed the share of group %2$s for %1$s" : "Odstranil(a) jsi sdílení skupině %2$s pro %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s odstranil(a) sdílení skupině %3$s pro %1$s",
    "%2$s shared %1$s via link" : "%2$s nasdílel(a) %1$s jako odkaz",
    "You shared %1$s via link" : "Sdílíte %1$s přes odkaz",
    "You removed the public link for %1$s" : "Odstranil(a) jsi veřejný odkaz na %1$s",
    "%2$s removed the public link for %1$s" : "%2$s odstranil(a) veřejný odkaz na %1$s",
    "Your public link for %1$s expired" : "Veřejný odkaz pro %1$s vypršel",
    "The public link of %2$s for %1$s expired" : "Veřejný odkaz na %2$s pro %1$s vypršel",
    "%2$s shared %1$s with you" : "%2$s s vámi sdílí %1$s",
    "%2$s removed the share for %1$s" : "%2$s odstranil(a) sdílení pro %1$s",
    "Downloaded via public link" : "Staženo pomocí veřejného odkazu",
    "Shared with %2$s" : "Sdíleno s %2$s",
    "Shared with %3$s by %2$s" : "%2$s sdílí s %3$s",
    "Removed share for %2$s" : "Odstranil(a) sdílení pro %2$s",
    "%2$s removed share for %3$s" : "%2$s odstranil(a) sdílení pro %3$s",
    "Shared with group %2$s" : "Sdíleno se skupinou %2$s",
    "Shared with group %3$s by %2$s" : "%2$s sdílí se skupinou %3$s",
    "Removed share of group %2$s" : "Odstranil(a) sdílení skupině %2$s",
    "%2$s removed share of group %3$s" : "%2$s odstranil(a) sdílení skupině %3$s",
    "Shared via link by %2$s" : "%2$s sdílel(a) jako odkaz",
    "Shared via public link" : "Sdíleno jako veřejný odkaz",
    "Removed public link" : "Odstranil(a) veřejný odkaz",
    "%2$s removed public link" : "%2$s odstranil(a) veřejný odkaz",
    "Public link expired" : "Veřejný odkaz vypršel",
    "Public link of %2$s expired" : "Veřejný odkaz %2$s vypršel",
    "Shared by %2$s" : "%2$s sdílel(a)",
    "Shares" : "Sdílení",
    "You received \"/%2$s\" as a remote share from %1$s" : "Obdržel(a) jsi \"/%2$s\" jako vzdálené sdílení od %1$s",
    "Accept" : "Přijmout",
    "Decline" : "Zamítnout",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Sdílej se mnou pomocí mého #ownCloud sdruženého cloud ID, více na %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Sdílej se mnou pomocí mého #ownCloud sdruženého cloud ID",
    "This share is password-protected" : "Toto sdílení je chráněno heslem",
    "The password is wrong. Try again." : "Heslo není správné. Zkuste to znovu.",
    "Password" : "Heslo",
    "No entries found in this folder" : "V tomto adresáři nebylo nic nalezeno",
    "Name" : "Název",
    "Share time" : "Čas sdílení",
    "Sorry, this link doesn’t seem to work anymore." : "Je nám líto, ale tento odkaz již není funkční.",
    "Reasons might be:" : "Možné důvody:",
    "the item was removed" : "položka byla odebrána",
    "the link expired" : "platnost odkazu vypršela",
    "sharing is disabled" : "sdílení je zakázané",
    "For more info, please ask the person who sent this link." : "Pro více informací kontaktujte osobu, která vám zaslala tento odkaz.",
    "Add to your ownCloud" : "Přidat do svého ownCloudu",
    "Download" : "Stáhnout",
    "Download %s" : "Stáhnout %s",
    "Direct link" : "Přímý odkaz",
    "Federated Cloud Sharing" : "Propojené cloudové sdílení",
    "Open documentation" : "Otevřít dokumentaci",
    "Allow users on this server to send shares to other servers" : "Povolit uživatelům z tohoto serveru zasílat sdílení na jiné servery",
    "Allow users on this server to receive shares from other servers" : "Povolit uživatelům z tohoto serveru přijímat sdílení z jiných serverů",
    "Federated Cloud" : "Sdružený cloud",
    "Your Federated Cloud ID:" : "Vaše sdružené cloud ID:",
    "Share it:" : "Sdílet:",
    "Add to your website" : "Přidat na svou webovou stránku",
    "Share with me via ownCloud" : "Sdíleno se mnou přes ownCloud",
    "HTML Code:" : "HTML kód:",
    "Public link of %2$s expired" : "Veřejný odkaz %2$s vypršel",
    "Public shared file %1$s was downloaded" : "Byl stažen veřejně sdílený soubor %1$s ",
    "Public shared folder %1$s was downloaded" : "Byl stažen veřejně sdílený adresář %1$s ",
    "Removed share for %2$s" : "Odstranil(a) sdílení pro %2$s",
    "Removed share of group %2$s" : "Odstranil(a) sdílení skupině %2$s",
    "Shared by %2$s" : "%2$s sdílel(a)",
    "Shared via link by %2$s" : "%2$s sdílel(a) jako odkaz",
    "Shared with group %3$s by %2$s" : "%2$s sdílí se skupinou %3$s",
    "The public link of %2$s for %1$s expired" : "Veřejný odkaz na %2$s pro %1$s vypršel",
    "You removed the public link for %1$s" : "Odstranil(a) jsi veřejný odkaz na %1$s",
    "You removed the share of %2$s for %1$s" : "Odstranil(a) jsi sdílení %2$s pro %1$s",
    "You removed the share of group %2$s for %1$s" : "Odstranil(a) jsi sdílení skupině %2$s pro %1$s",
    "Your public link for %1$s expired" : "Veřejný odkaz pro %1$s vypršel"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
